diff_objects

Function diff_objects 

pub fn diff_objects(
    a: &HashMap<String, Value>,
    b: &HashMap<String, Value>,
) -> DiffResult
Compute a structural diff between two SYNX objects (top-level keys).

Keys present only in b appear in added. Keys present only in a appear in removed. Keys present in both but with different values appear in changed. Keys present in both with equal values appear in unchanged.